import React, { useEffect, useState } from 'react'
import { Card, Input, Modal, ModalFooter, ModalBody, Button } from 'reactstrap'
import { config } from '../../config/main'
import axios from 'axios';

export const OrderDetails = ({ update, saveOrder }) => {

    const [searchProduct, setSearchProduct] = useState("")
    const [allProducts, setAllProducts] = useState([])
    const [choiceProducts, setChoiceProduct] = useState([])
    const [showPopup, setShowPopup] = useState(false)
    const [subTotal, setSubTotal] = useState(0)
    const [paymentStatus, setPaymentStatus] = useState("")

    useEffect(() => { fetchAllProducts() }, [])

    useEffect(() => {
        console.log(saveOrder)
        if (saveOrder && choiceProducts.length !== 0) {

            createNewOrder()
        }
    }, saveOrder)

    useEffect(() => {

        if (choiceProducts.length !== 0) {

            choiceProducts.forEach(prod => subTotal += prod.pricing * prod.quantity)
        }
    }, [choiceProducts])

    const createNewOrder = async () => {
        try {

            let url = config.API + "/create-order"

            let token = sessionStorage.getItem("token")

            console.log(choiceProducts)

            if (token) { 

                console.log({ products: choiceProducts, paymentStatus, })

                let res = await axios({ 
                    url, 
                    method: "POST", 
                    headers : { token },
                    data: {
                        products: choiceProducts,
                        paymentStatus,
                    }
                })

                console.log(res.data)

            }

        } catch (err) {
            console.log(err)
        }
    }

    const fetchAllProducts = async () => {
        try { 

            let url = config.API + "/get-products"

            let token = sessionStorage.getItem("token")

            if (token) { 

                let res = await axios({ url, method: "GET", headers : { token } })

                let products = res.data.result

                if (!products || products.length === 0) { 
                    alert("error fetching products data.")
                }

                console.log(products)

                setAllProducts(products)

            }
        } catch (err) {
            console.log(err)
        }
    }

    const productSelected = (productId) => {

        let product = allProducts.filter(prod => prod.productid == productId)[0]

        setChoiceProduct([
            ...choiceProducts,
            {
                productid: productId,
                product: product.product,
                pricing: product.pricing,
                quantity: 0,
                total: product.pricing
            }
        ])
    } 

    const updateQty = (idx) => {

        choiceProducts[idx].quantity += 1

        setChoiceProduct([ ...choiceProducts ])
    }

    return (
        <Card className="p-3 mt-4 mb-4">

            <h3> order details </h3>

            <Modal isOpen={showPopup} toggle={() => setShowPopup(!showPopup)} centered>
                    
                <ModalBody className="p-3">

                    <div style={{height: "300px", overflowY: "scroll", overflowX: "hidden"}}>

                        { allProducts.map(product => {
                            return (
                                <div style={{display: "flex", justifyContent: "space-between"}}>
                                    
                                    <input 
                                        type="checkbox" 
                                        value={product.productid}
                                        onClick={(e) => productSelected(e.target.value)}
                                    />

                                    <p> { product.product } </p>

                                    <p> { product.pricing } </p>

                                </div>
                            )
                        }) }
                    </div>
                </ModalBody>

                <ModalFooter>
                    
                    <Button  
                        style={{background : "#ff4c3b", border: "none"}}
                        onClick={() => setShowPopup(!showPopup)}
                    >
                        add
                    </Button>

                    <Button color="secondary" onClick={() => setShowPopup(!showPopup)}>
                        Cancel
                    </Button>

                </ModalFooter>

            </Modal>

            <div>
                <div style={{display: "flex", flexDirection:"row"}}> 
                        
                    <Input  
                        type="text"
                        placeholder="search product"
                        value={searchProduct}
                        onChange={e => setSearchProduct(e.target.value)}
                    />

                    
                    <button className="btn btn-secondary ml-2" onClick={() => setShowPopup(true)}> 
                        Browse 
                    </button>
                      
                </div>
                
                <div>
                    { !showPopup && choiceProducts.length !== 0 ?
                        <div>
                            
                            <table className="table-responsive-md table mb-0">
                                <thead>
                                    <tr>
                                        <th scope="col"> Product </th>
                                        <th scope="col"> Quantity </th>
                                        <th scope="col"> Total </th>
                                    </tr>
                                </thead>
                                <tbody>
                                    
                                    { choiceProducts.map((product, idx) => {
                                        return (
                                            <tr> 

                                                <td> <p> {product.product} </p> </td>

                                                <td> 
                                                    <input
                                                        type="number"
                                                        value={product.quantity}
                                                        onChange={() => updateQty(idx)}
                                                    />    
                                                </td>

                                                <td> { product.pricing * product.quantity } </td>

                                            </tr>
                                        )
                                    }) }
                                    
                                </tbody>
                            </table>

                        </div>: 
                        null
                    }
                </div>
                
                <div style={{height: "2px", background: "#d8d8d8"}}></div>
                
                <div className="mt-3 p-3 border">

                    <div className="p-3" style={{width: "30%"}}>

                        <div style={{display: "flex", justifyContent: "space-between"}}>

                            <p> sub total </p>

                            <p> {subTotal} </p> 
                        </div>

                        <div style={{display: "flex", justifyContent: "space-between"}}>

                            <p> Add Discount </p>
                            <p> -- </p>
                        </div>

                        <div style={{display: "flex", justifyContent: "space-between"}}>

                            <p> Add Shipping </p>
                            <p> -- </p>
                        </div>
                        
                        <div style={{display: "flex", justifyContent: "space-between"}}>
                            <p> Tax </p>
                            <p> -- </p>
                        </div>
                        
                        <div style={{display: "flex", justifyContent: "space-between"}}>
                            <b> Total </b>
                            <p> {subTotal} </p>
                        </div>

                    </div>
                </div>
                
                <div style={{height: "2px", background: "#d8d8d8"}} className="mt-2 mb-2"></div>

                <div className="mt-3 p-3" style={{display: "flex", justifyContent: "space-between", alignItems: "center"}}>

                    <h4> PAYMENT </h4>

                    <div>

                        <Button 
                            className="m-2" 
                            outline={ paymentStatus === "Mark as paid" ? true : false }
                            onClick={() => setPaymentStatus("Mark as paid")}
                        > 
                            Mark as paid 
                        </Button>

                        <Button 
                            className="m-2" 
                            outline={ paymentStatus === "Mark as pending" ? true : false }
                            onClick={() => setPaymentStatus("Mark as pending")}
                        >
                            Mark as pending 
                        </Button> 

                        <Button 
                            className="m-2" 
                            outline={ paymentStatus === "Pay by credit card" ? true : false }
                            onClick={() => setPaymentStatus("Pay by credit card")}
                        > 
                            Pay by credit card 
                        </Button> 

                    </div>
            
                </div>

            </div>
        </Card>
    )
}