import React, { useContext, useEffect, useState } from 'react'
import { useRouter } from 'next/router'
import { Row, Col, Media, Card, CardBody, TabPane,Button } from 'reactstrap';
import axios from 'axios';
import { config } from '../../config/main'

export const ViewAllOrders = () => {

    const router = useRouter()
    const [orders, setOrders] = useState([])


    useEffect(() => { getAllOrders() }, [])


    const getAllOrders = async () => {

        try {

            let url = config.API + "/get-orders"

            let token = sessionStorage.getItem("token")

            if (token) { 

                let res = await axios({ url, method: "GET", headers : { token } })

                if (!res.data.result) {
                    alert("err fetching data.")
                }

                if (Array.isArray(res.data.result)) setOrders(res.data.result)

            }
        } catch (err) {

            console.log(err)
        }
    }

    const toNewOrder = () => router.push("/orders/new")

    return (
        <div className="col">
            <TabPane tabId="2">
                <Row>
                    <Col sm="12">
                        <Card className="dashboard-table mt-0">
                            <CardBody>
                                <div className="top-sec mb-3" style={{display: "flex",alignContent:"center",justifyContent:"space-between"}}>

                                    <h3 className="m-3 text-dark"> Orders </h3>

                                    <div>   

                                        <button className="btn btn-sm m-3 btn-light"> Export </button>

                                        <button 
                                            className="btn btn-sm btn-solid m-3"
                                            onClick={() => toNewOrder()}
                                        > 
                                            create order 
                                        </button>

                                    </div>
                                </div>
                                <table className="table-responsive-md table mb-0">
                                    <thead>
                                        <tr>
                                            <th scope="col"> Order </th>
                                            <th scope="col"> Date </th>
                                            <th scope="col"> Status </th>
                                            <th scope="col"> Total </th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        
                                        { orders.length !== 0 ? 
                                            <React.Fragment>
                                                { orders.map((order, idx) => {

                                                    return (
                                                            <tr>
                                                                <td>
                                                                    <a href={`http://localhost:4000/orders/${order.orderid}`}>
                                                                        { order.orderid }
                                                                    </a>
                                                                </td> 
                                                                <td> { new Date(order.date).toDateString().slice(4,).replace(" ", ",")} </td>
                                                                <td> 
                                                                    { order.status == 1 ? "Paid" : "Unpaid" } 
                                                                </td>
                                                                <td> { order.total } </td>
                                                            </tr>
                                                        )
                                                    }) 
                                                }
                                            </React.Fragment>
                                            : null
                                        }

                                        
                                    </tbody>
                                </table>
                            </CardBody>
                        </Card>
                    </Col>
                </Row>
            </TabPane>   
        </div>
    )
}