import React, { useContext, useEffect, useState } from 'react'
import { useRouter } from 'next/router'
import { Row, Col, Media, Card, CardBody, TabPane, Button, DropdownMenu, Label, Input, FormGroup, Container } from 'reactstrap';
import { ProductContext } from '../../context/products';
import { config } from '../../config/main'
import axios from 'axios';

export const ViewAllProducts = () => {

    const router = useRouter()
    const productContext = useContext(ProductContext)
    const [dropDown, setDropDown] = useState(false)


    const toNewProduct = () => { router.push("/product/new") }

    const goToProduct = async (id) => { router.push(`/product/${id}`) }

    const sortBy = async (val) => {
        try { 

            let url = config.API + dropDown ? `/get-products?${val}=true` : "/get-products"

            let token = sessionStorage.getItem("token")

            if (token) { 

                let res = await axios({ url, method: "GET", headers : { token } })

                let products = res.data.result
                console.log(products)
                if (!products || products.length === 0) { 
                alert("error fetching products data.")
                }

                productContext.dispatch({ 
                    type: "setAllProducts", 
                    payload : { products : products }
                })

            }
        } catch (err) {
            console.log(err)
        }
    }

    return (
        <div className="col">
            <TabPane tabId="2">
                <Row>
                    <Col sm="12">
                        <Card className="dashboard-table mt-0">
                            <CardBody>
                                <div className="top-sec mb-3" style={{display: "flex",alignContent:"center",justifyContent:"space-between"}}>

                                    <h3 className="m-3 text-dark">products</h3>

                                    <div>   

                                        <button className="btn btn-sm m-3 btn-light"> Import  </button>

                                        <button className="btn btn-sm m-3 btn-light"> Export </button>

                                        <button 
                                            className="btn btn-sm btn-solid m-3"
                                            onClick={() => toNewProduct()}
                                        > 
                                            add product 
                                        </button>

                                    </div>
                                </div>
                                <div className="border-top p-3">

                                    <Button 
                                        onClick={() => setDropDown(!dropDown)}
                                        style={{position: "relative"}}
                                    > 
                                        sort 
                                    </Button>

                                    { dropDown ?  
                                        <Card 
                                            style={{position: "absolute", width: "20%"}} 
                                            className="p-1 text-center"
                                        >
                                            <Label className="p-1">
                                                <Input 
                                                    name="sort"
                                                    type="radio"
                                                    value="sortbyidasc"
                                                    onClick={(e) => sortBy(e.target.value)}
                                                />
                                                id asc
                                            </Label>

                                            <Label className="p-1">
                                                <Input 
                                                    name="sort"
                                                    type="radio"
                                                    value="sortbyiddesc"
                                                    onClick={(e) => sortBy(e.target.value)}
                                                />
                                                id dsc
                                            </Label>

                                            <Label className="p-1">
                                                <Input 
                                                    name="sort"
                                                    type="radio"
                                                    value="sortbynameaz"
                                                    onClick={(e) => sortBy(e.target.value)}
                                                />
                                                Name A-Z
                                            </Label>

                                            <Label className="p-1">
                                                <Input 
                                                    name="sort"
                                                    type="radio"
                                                    value="sortbynameza"                                                    onClick={(e) => sortBy(e.target.value)}
                                                    onClick={(e) => sortBy(e.target.value)}
                                                />
                                                Name Z-A
                                            </Label>

                                            <Label className="p-1">
                                                <Input 
                                                    name="sort"
                                                    type="radio"
                                                    value="sortbydatenew"
                                                    onClick={(e) => sortBy(e.target.value)}
                                                />
                                                Date New
                                            </Label>

                                            <Label className="p-1">
                                                <Input 
                                                    name="sort"
                                                    type="radio"
                                                    value="sortbydateold"
                                                    onClick={(e) => sortBy(e.target.value)}
                                                />
                                                Date Old
                                            </Label>
                                        </Card> : null
                                    }

                                </div>
                                <table className="table-responsive-md table mb-0">
                                    <thead>
                                        <tr>
                                            <th scope="col"> </th>
                                            <th scope="col"> Product </th>
                                            <th scope="col"> Status </th>
                                            <th scope="col"> Inventory </th>
                                            <th scope="col"> Type </th>
                                            <th scope="col"> Vendor </th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        { productContext.state.products.map((product, idx) => {
                                            return (
                                                    <tr>
                                                        <td scope="row"><Media className="blur-up lazyloaded"/></td>
                                                        <td onClick={() => goToProduct(product.productid)}> 
                                                            <a href={`/product/${product.productid}`}>
                                                                { product.product} 
                                                            </a>
                                                        </td>
                                                        <td> { product.status } </td>
                                                        <td> { product.inventory } </td>
                                                        <td> { product.type } </td>
                                                        <td> { product.vendor } </td>
                                                    </tr>
                                                )
                                            }) 
                                        }
                                    </tbody>
                                </table>
                            </CardBody>
                        </Card>
                    </Col>
                </Row>
            </TabPane>   
        </div>
    )
}