import React, { useContext, useReducer } from 'react'
import { createContext } from 'react'

const initState = {
    products : [],
    newProduct : {}
}

const reducer = (state, action) => {

    switch (action.type) {

        case "setAllProducts":
            return {
                ...state,
                products : [ ...action.payload.products ]
            }

        case "addProduct":
            return {
                ...state,
                products : [ ...state.products, action.payload.product ]
            }

        case "updateProduct":
            return { 
                ...state,
                newProduct : { ...state.newProduct, ...action.payload }
            }
    
        case "deleteProduct":
            return {
                ...state,
                ...state.products.filter(product => {
                    if (product.productid !== action.payload.productId) { 
                        return product
                    }
                })
            }
            

        default:
            return state
    }
}

export const ProductContext = createContext()

export const ProductProvider = (props) => {

    const [state, dispatch] = useReducer(reducer, initState)

    return (
        <React.Fragment>
            <ProductContext.Provider
                value={{state, dispatch}}
            >
                {props.children}
            </ProductContext.Provider>
        </React.Fragment>
    )
} 