import React, { useEffect, useState } from 'react';
import { Container, Row, Label, Input ,Col} from 'reactstrap';
import axios from 'axios';
import FooterOne from '../components/footers/footer-one'
import { useRouter } from 'next/router'

const Login = () => {

    const router = useRouter()

    const [email, setEmail] = useState("")
    const [password, setPassword] = useState("")
    const [err, setErr] = useState(false)
    const [errMsg, setErrMsg] = useState("")
    const [loading, setLoading] = useState(false)

    useEffect(() => {

        setErr(false)
        setErrMsg("")

    }, [email, password])

    const validateEmail = () => {

        const emailRegx = /^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i

        return emailRegx.test(email) ? true : false 
    }

    const showErr = (msg) => {
        setErr(true)
        setErrMsg(msg)
    }

    const login = async () => {

        if (email.length === 0 || password.length === 0) {
            showErr("all fields are required")            
            return 
        }   

        if (!validateEmail(email)) {
            showErr("invalid email.")
            return
        }

        try {

            setLoading(true)

            const res = await axios({
                method: 'post',
                url: 'https://elitecarthub.com/Development/API/swaggerapi/api/user-login',
                headers: { 
                    'Content-Type': 'application/json'
                },
                data : JSON.stringify({ email, password })
            })

            setLoading(false)

            const { success, err } = res.data

            console.log(err)

            if (err || success.token.length === 0) {
                showErr(res.data.err)
                return 
            }

            sessionStorage.setItem("token", success.token)

            window.location = "/"

        } catch (err) {

            setLoading(false)

            showErr("incorrect email or password.")
        }
    }

    const redirectToForgotpwd = () => router.push("/forgot-password")

    return (
        <>            
            <section className="login-page section-b-space">
                <Container>
                    <Row>
                        <Col lg="6">
                            <h3>Login</h3>
                            <div className="theme-card">
                                <div className="theme-form" action="">

                                    { err ? 
                                        <p className="err-msg"> 
                                            { errMsg } 
                                        </p> : 
                                        null
                                    }

                                    { loading ? 
                                        <p className="loading-msg"> loading </p> :
                                        null
                                    }

                                    <div className="form-group">
                                        <Label for="email">Email</Label>
                                        <Input 
                                            type="text" 
                                            className="form-control" 
                                            id="email" 
                                            placeholder="Email" 
                                            required=""
                                            onChange={(e) => setEmail(e.target.value)}
                                        />
                                    </div>

                                    <div className="form-group">
                                        <Label for="review">Password</Label>
                                        <Input 
                                            type="password" 
                                            className="form-control" 
                                            id="review"
                                            placeholder="Enter your password" 
                                            required="" 
                                            onChange={(e) => setPassword(e.target.value)}
                                        />
                                    </div>

                                    <button 
                                        className="btn btn-solid"
                                        onClick={login}
                                    >
                                        Login
                                    </button>

                                    <p id="forgot-password" onClick={() => redirectToForgotpwd()}> 
                                        forgot password? 
                                    </p>
                                
                                </div>
                            </div>
                        </Col>
                        <Col lg="6" className="right-login">
                            <h3>New Customer</h3>
                            <div className="theme-card authentication-right">
                                <h6 className="title-font">Create A Account</h6>
                                <p>
                                    Sign up for a free account at our store. 
                                    Registration is quick and easy. 
                                    It allows you to be able to order from our shop. 
                                    To start shopping click register.
                                </p>
                                
                                <a 
                                    href="/register" 
                                    className="btn btn-solid"
                                >
                                    Create an Account
                                </a>
                            </div>
                        </Col>
                    </Row>
                </Container>
            </section>
            <FooterOne />
        </>
    )
}

export default Login;