import React, { useState, useEffect } from 'react'
import { Row, Col, Container,Card, Input, Modal, ModalFooter, ModalBody, Button } from 'reactstrap'
import { useRouter } from 'next/router'
import CommonLayout from '../../components/shop/common-layout'
import { config } from '../../config/main'
import axios from 'axios';
import { route } from 'next/dist/next-server/server/router'


const NewOrder = () => {

    const router = useRouter()

    const backToProduct = () => router.push("/product")
    const [searchProduct, setSearchProduct] = useState("")
    const [allProducts, setAllProducts] = useState([])
    const [choiceProducts, setChoiceProduct] = useState([])
    const [showPopup, setShowPopup] = useState(false)
    const [subTotal, setSubTotal] = useState(0)
    const [paymentStatus, setPaymentStatus] = useState("")
    const [orderProducts, setOrderProducts] = useState([])

    useEffect(() => { fetchAllProducts() }, [])

    useEffect(() => {


        if (choiceProducts.length !== 0) {

            let total = 0

            choiceProducts.forEach(prod => total += prod.pricing * prod.qty)

            setSubTotal(total)
        }
    }, [choiceProducts])

    const createNewOrder = async () => {
        try {

            let url = config.API + "/create-order"

            let token = sessionStorage.getItem("token")

            if (!token || choiceProducts.length === 0) {
                alert("add some products.")
                return 
            }

            console.log(choiceProducts, paymentStatus, subTotal)

            let res = await axios({ 
                url, 
                method: "POST", 
                headers : { token },
                data: {
                    "total" : subTotal,
                    "payment_status" : paymentStatus,
                    "products" : choiceProducts
                }
            })

            if (res.data.status) {
                alert("product added successfully.")
                router.push("/orders")
            }

        } catch (err) {
            console.log(err)
        }
    }

    const fetchAllProducts = async () => {
        try { 

            let url = config.API + "/get-products"

            let token = sessionStorage.getItem("token")

            if (token) { 

                let res = await axios({ url, method: "GET", headers : { token } })

                let products = res.data.result

                if (!products || products.length === 0) { 
                    alert("error fetching products data.")
                }

                console.log(products)

                setAllProducts(products)

            }
        } catch (err) {
            console.log(err)
        }
    }

    const productSelected = (productId) => {

        let product = allProducts.filter(prod => prod.productid == productId)[0]
        console.log(product)
        setChoiceProduct([
            ...choiceProducts,
            {
                product_id: productId,
                product: product.product,
                pricing: parseInt(product.pricing),
                qty: 1,
                total: parseInt(product.pricing)
            }
        ])

        setOrderProducts([
            ...orderProducts,
            {
                product_id: productId,
                product: product.product,
                qty: 1
            }
        ])
    } 

    const updateQty = (idx) => {

        choiceProducts[idx].qty += 1

        setChoiceProduct([ ...choiceProducts ])
    }

    const removeProduct = (product) => {

        let newProducts = choiceProducts.filter(prod => prod.product_id !== product.product_id)
        setChoiceProduct([...newProducts])
    }

    return (
        <CommonLayout parent="new" title="order">
            <section className="section-b-space">
                <Container>
                    <Row>

                        <Col lg="3">

                            <div className="dashboard-left"> 
                                <div className="collection-mobile-back" onClick={() => setAccountInfo(!accountInfo)}>
                                    <span className="filter-back">
                                        <i className="fa fa-angle-left" aria-hidden="true"></i> back
                                    </span>
                                </div>
                                
                                <div className="block-content">
                                    <ul>
                                        <li className="active"><a href="#">Account Info</a></li>
                                        <li><a href="#">Address Book</a></li>
                                        <li><a href="#">My Orders</a></li>
                                        <li><a href="#">My Wishlist</a></li>
                                        <li><a href="#">Newsletter</a></li>
                                        <li><a href="#">My Account</a></li>
                                        <li><a href="#">Change Password</a></li>
                                        <li className="last"><a href="#">Log Out</a></li>
                                    </ul>
                                </div>
                            </div>

                        </Col>

                        <Col lg="9" className="">
                        
                            <div className="">
                                <Row className="">
                                    
                                    <button id="btn" onClick={() => backToProduct()}> 
                                        back 
                                    </button> 

                                    <h3 id="product-name"> Create order </h3>
                                    
                                </Row>
                            </div>

                            <Row className="">
                                <Col className="p-0 m-0">

                                <Card className="p-3 mt-4 mb-4">

                                    <h3> order details </h3>

                                    <Modal isOpen={showPopup} toggle={() => setShowPopup(!showPopup)} centered>
                                            
                                        <ModalBody className="p-3">

                                            <div style={{height: "300px", overflowY: "scroll", overflowX: "hidden"}}>

                                                { allProducts.map(product => {
                                                    return (
                                                        <div style={{display: "flex", justifyContent: "space-between"}}>
                                                            
                                                            <input 
                                                                type="checkbox" 
                                                                value={product.productid}
                                                                onClick={(e) => productSelected(e.target.value)}
                                                            />

                                                            <p> { product.product } </p>

                                                            <p> { product.pricing } </p>

                                                        </div>
                                                    )
                                                }) }
                                            </div>
                                        </ModalBody>

                                        <ModalFooter>
                                            
                                            <Button  
                                                style={{background : "#ff4c3b", border: "none"}}
                                                onClick={() => setShowPopup(!showPopup)}
                                            >
                                                add
                                            </Button>

                                            <Button color="secondary" onClick={() => setShowPopup(!showPopup)}>
                                                Cancel
                                            </Button>

                                        </ModalFooter>

                                    </Modal>

                                    <div>
                                        <div style={{display: "flex", flexDirection:"row"}}> 
                                                
                                            <Input  
                                                type="text"
                                                placeholder="search product"
                                                value={searchProduct}
                                                onChange={e => setSearchProduct(e.target.value)}
                                            />

                                            
                                            <button className="btn btn-secondary ml-2" onClick={() => setShowPopup(true)}> 
                                                Browse 
                                            </button>
                                            
                                        </div>
                                        
                                        <div>
                                            { !showPopup && choiceProducts.length !== 0 ?
                                                <div>
                                                    
                                                    <table className="table-responsive-md table mb-0">
                                                        <thead>
                                                            <tr>
                                                                <th scope="col"> Product </th>
                                                                <th scope="col"> Quantity </th>
                                                                <th scope="col"> Total </th>
                                                                <th></th>
                                                            </tr>
                                                        </thead>
                                                        <tbody>
                                                            
                                                            { choiceProducts.map((product, idx) => {
                                                                let total = product.pricing * product.qty
                                                                return (
                                                                    <tr> 

                                                                        <td> <p> {product.product} </p> </td>

                                                                        <td> 
                                                                            <input
                                                                                type="number"
                                                                                value={product.qty}
                                                                                onChange={() => updateQty(idx)}
                                                                            />    
                                                                        </td>

                                                                        <td> 
                                                                            { total }                                                                            
                                                                        </td>

                                                                        <td>
                                                                            <Button 
                                                                                size="sm" 
                                                                                className="p-1 ml-3"
                                                                                onClick={() => removeProduct(product)}
                                                                            > X </Button>
                                                                        </td>
                                                                    </tr>
                                                                )
                                                            }) }
                                                            
                                                        </tbody>
                                                    </table>

                                                </div>: 
                                                null
                                            }
                                        </div>
                                        
                                        <div style={{height: "2px", background: "#d8d8d8"}}></div>
                                        
                                        <div className="mt-3 p-3 border">

                                            <div className="p-3" style={{width: "30%"}}>

                                                <div style={{display: "flex", justifyContent: "space-between"}}>

                                                    <p> sub total </p>

                                                    <p> {subTotal} </p> 
                                                </div>

                                                <div style={{display: "flex", justifyContent: "space-between"}}>

                                                    <p> Add Discount </p>
                                                    <p> -- </p>
                                                </div>

                                                <div style={{display: "flex", justifyContent: "space-between"}}>

                                                    <p> Add Shipping </p>
                                                    <p> -- </p>
                                                </div>
                                                
                                                <div style={{display: "flex", justifyContent: "space-between"}}>
                                                    <p> Tax </p>
                                                    <p> -- </p>
                                                </div>
                                                
                                                <div style={{display: "flex", justifyContent: "space-between"}}>
                                                    <b> Total </b>
                                                    <p> {subTotal} </p>
                                                </div>

                                            </div>
                                        </div>
                                        
                                        <div style={{height: "2px", background: "#d8d8d8"}} className="mt-2 mb-2"></div>

                                        <div className="mt-3 p-3" style={{display: "flex", justifyContent: "space-between", alignItems: "center"}}>

                                            <h4> PAYMENT </h4>

                                            <div>

                                                <Button 
                                                    className="m-2" 
                                                    outline={ paymentStatus === "Mark as paid" ? true : false }
                                                    onClick={() => setPaymentStatus("Mark as paid")}
                                                > 
                                                    Mark as paid 
                                                </Button>

                                                <Button 
                                                    className="m-2" 
                                                    outline={ paymentStatus === "Mark as pending" ? true : false }
                                                    onClick={() => setPaymentStatus("Mark as pending")}
                                                >
                                                    Mark as pending 
                                                </Button> 

                                                <Button 
                                                    className="m-2" 
                                                    outline={ paymentStatus === "Pay by credit card" ? true : false }
                                                    onClick={() => setPaymentStatus("Pay by credit card")}
                                                > 
                                                    Pay by credit card 
                                                </Button> 

                                            </div>

                                        </div>

                                    </div>
                                    </Card>

                                </Col>
                            </Row>

                            <Row>
                                
                                <button 
                                    className="btn btn-sm btn-solid m-3"
                                    onClick={() => createNewOrder()}
                                > 
                                    save
                                </button>

                            </Row>
                        </Col>
                    </Row>
                </Container>
            </section>
        </CommonLayout>
    )
}

export default NewOrder

