import React, { useContext, useEffect, useState } from 'react'
import { ViewAllProducts } from '../components/products/view-all-products'
import CommonLayout from '../components/shop/common-layout'
import { Row, Col, Container } from 'reactstrap'
import { ProductContext } from '../context/products'
import axios from 'axios'
import { config } from '../config/main'

const Products = () => {

    const productContext = useContext(ProductContext)

    useEffect(() => {

        getAllProducts()

    }, [])

    const getAllProducts = async () => {

        try { 

            let products = productContext.state.products

            if (products.length === 0) { 

                let url = config.API + "/get-products"

                let token = sessionStorage.getItem("token")

                if (token) { 

                    let res = await axios({ url, method: "GET", headers : { token } })

                    let products = res.data.result
                    console.log(products)
                    if (!products || products.length === 0) { 
                       alert("error fetching products data.")
                    }

                    productContext.dispatch({ 
                        type: "setAllProducts", 
                        payload : { products : products }
                    })

                }
            }
        } catch (err) {
            console.log(err)
        }
    }

    return (
        <CommonLayout parent="home" title="dashboard">
            <section className="section-b-space">
                <Container>
                    <Row>

                        <Col lg="3">
                            <div className="dashboard-left"> 
                                <div className="collection-mobile-back" onClick={() => setAccountInfo(!accountInfo)}>
                                    <span className="filter-back">
                                        <i className="fa fa-angle-left" aria-hidden="true"></i> back
                                    </span>
                                </div>
                                <div className="block-content">
                                    <ul>
                                        <li className="active"><a href="#">Account Info</a></li>
                                        <li><a href="#">Address Book</a></li>
                                        <li><a href="#">My Orders</a></li>
                                        <li><a href="#">My Wishlist</a></li>
                                        <li><a href="#">Newsletter</a></li>
                                        <li><a href="#">My Account</a></li>
                                        <li><a href="#">Change Password</a></li>
                                        <li className="last"><a href="#">Log Out</a></li>
                                    </ul>
                                </div>
                            </div>
                        </Col>

                        <Col lg="9" className="">
                            
                            <ViewAllProducts />
                            
                        </Col>
                    </Row>
                </Container>
            </section>
        </CommonLayout>
    )
}

export default Products

