import React, { useContext } from 'react'
import { Inventory } from '../../components/new-product/inventory'
import { Media } from '../../components/new-product/media'
import { Pricing } from '../../components/new-product/pricing'
import { TitleAndDescription } from '../../components/new-product/title-and-description'
import { Shipping } from '../../components/new-product/shipping'
import { Variants } from '../../components/new-product/variants'
import { Seo } from '../../components/new-product/seo'
import { ProductStatus } from '../../components/new-product/product-status'
import { OnlineStore } from '../../components/new-product/online-store'
import { Organization } from '../../components/new-product/organization'
import { Row, Col, Container, } from 'reactstrap'
import { useRouter } from 'next/router'
import CommonLayout from '../../components/shop/common-layout'
import { ProductContext } from '../../context/products'
import axios from 'axios'
import { config } from '../../config/main'

const NewProduct = () => {

    const router = useRouter()
    const productContext = useContext(ProductContext)

    const backToProduct = () => {

        router.push("/product")
    }    

    const saveProduct = async () => {

        try { 

            let url = config.API + "/create-product"

            let token = "Bearer" + sessionStorage.getItem("token")

            let product = productContext.state.newProduct

            if (token) { 

                let res = await axios({ 
                    url, 
                    method: "POST", 
                    headers : { token },
                    body: JSON.stringify(productContext.state.newProduct)
                })

                console.log(res.data, res)

                let products = res.data.result

                // if (!products || products.length === 0) { 
                //     alert("error fetching products data.")
                // }

                productContext.dispatch({ 
                    type: "addProduct", 
                    payload : { product }
                })

                alert("product added")

                router.push("/product")
            }
        } catch (err) {
            console.log(err)
            alert("error adding product")
        }
    }

    return (
        <CommonLayout parent="new" title="product">
            <section className="section-b-space">
                <Container>
                    <Row>

                        <Col lg="3">

                            <div className="dashboard-left"> 
                                <div className="collection-mobile-back" onClick={() => setAccountInfo(!accountInfo)}>
                                    <span className="filter-back">
                                        <i className="fa fa-angle-left" aria-hidden="true"></i> back
                                    </span>
                                </div>
                                
                                <div className="block-content">
                                    <ul>
                                        <li className="active"><a href="#">Account Info</a></li>
                                        <li><a href="#">Address Book</a></li>
                                        <li><a href="#">My Orders</a></li>
                                        <li><a href="#">My Wishlist</a></li>
                                        <li><a href="#">Newsletter</a></li>
                                        <li><a href="#">My Account</a></li>
                                        <li><a href="#">Change Password</a></li>
                                        <li className="last"><a href="#">Log Out</a></li>
                                    </ul>
                                </div>
                            </div>

                        </Col>

                        <Col lg="9" className="">
                        
                            <div className="">
                                <Row className="">
                                    
                                    <button id="btn" onClick={() => backToProduct()}> 
                                        back 
                                    </button> 

                                    <h3 id="product-name"> Product name </h3>
                                    
                                    <p id="product-status"> active </p> 

                                </Row>
                            </div>

                                
                            <Row className="">
                            
                                <Col className="p-0 m-0">

                                    <Col> <TitleAndDescription /> </Col>

                                    <Col> <Media /> </Col>

                                    <Col> <Pricing /> </Col>

                                    <Col> <Inventory /> </Col>

                                    <Col> <Shipping /> </Col>

                                </Col>
                                
                                <Col className="p-0 m-0" xs="5">

                                    <Col> <Variants /> </Col>

                                    <Col> <Seo /> </Col>

                                    <Col> <ProductStatus /> </Col>

                                    <Col> <Organization /> </Col>

                                    <Col> <OnlineStore /> </Col>

                                </Col>
                            </Row>

                            <Row>
                                
                                <button 
                                    className="btn btn-sm btn-solid m-3"
                                    onClick={() => saveProduct()}
                                > 
                                    save
                                </button>

                            </Row>
                        </Col>
                    </Row>
                </Container>
            </section>
        </CommonLayout>
    )
}

export default NewProduct