import React, { useState, useEffect } from 'react';
import CommonLayout from '../components/shop/common-layout';
import { Input, Container, Row, Label ,Col} from 'reactstrap';
import axios from 'axios';
import FooterOne from '../components/footers/footer-one'

const Register = () => {

    const [firstName, setFirstName] = useState("")
    const [lastName, setLastName] = useState("")
    const [email, setEmail] = useState("")
    const [password, setPassword] = useState("")
    const [err, setErr] = useState(true)
    const [errMsg, setErrMsg] = useState("asd")
    const [loading, setLoading] = useState(false)

    
    useEffect(() => {

        setErr(false)
        setErrMsg("")

    }, [email, password, firstName, lastName])


    const showErr = (msg) => {
        setErr(true)
        setErrMsg(msg)
    }

    const validateEmail = () => {

        const emailRegx = /^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i

        return emailRegx.test(email) ? true : false 
    }


    const signUp = async () => {

        if (firstName.length === 0 || lastName.length === 0 || 
            email.length === 0 || password.length === 0) {
                showErr("all fields are required")
                return 
        }

        if (!validateEmail(email)) {
            showErr("invalid email.")
            return
        }

        try {

            setLoading(true)

            const res = await axios({
                method: 'post',
                url: 'https://elitecarthub.com/Development/API/swaggerapi/api/user-register',
                headers: { 
                    'Content-Type': 'application/json'
                },
                data : JSON.stringify({ 
                    "firstname" : firstName, 
                    "lastname" : lastName,
                    "email" : email,
                    "password": password ,
                    "password_confirmation": password
                })
            })

            setLoading(false)

            console.log(res)

            const { success, err } = res.data

            if (err || success.token.length === 0) {
                showErr(res.data.err)
                return 
            }

            sessionStorage.setItem("token", success.token)

            window.location = "/"


        } catch (err) {
            console.log(err)
            setLoading(false)
            showErr("invalid request")
        }
    }

    return (
        // <CommonLayout parent="home" title="register">
        <>
            <section className="register-page section-b-space">
                <Container>
                    <Row>
                        <Col lg="12">
                            <h3>create account</h3>
                            <div className="theme-card">

                                { err ? 
                                    <p className="err-msg"> 
                                        { errMsg } 
                                    </p> : 
                                    null
                                }

                                { loading ? 
                                    <p className="loading-msg"> loading </p> :
                                    null
                                }

                                <div className="theme-form">
                                    <Row>
                                        <Col md="6">
                                            <Label for="email">First Name</Label>
                                            <Input 
                                                type="text" 
                                                className="form-control" 
                                                id="fname" 
                                                placeholder="First Name"
                                                required="" 
                                                onChange={e => setFirstName(e.target.value)}

                                            />
                                        </Col>
                                        <Col md="6">
                                            <Label for="review">Last Name</Label>
                                            <Input 
                                                type="text" 
                                                className="form-control" 
                                                id="lname" 
                                                placeholder="Last Name"
                                                required="" 
                                                onChange={e => setLastName(e.target.value)}
                                            />
                                        </Col>
                                    </Row>
                                    <Row>
                                        
                                        <Col md="6">
                                            <Label for="email">email</Label>
                                            <Input 
                                                type="text" 
                                                className="form-control" 
                                                id="email" 
                                                placeholder="Email" 
                                                required="" 
                                                onChange={e => setEmail(e.target.value)}
                                            />
                                        </Col>
                                        
                                        <Col md="6">
                                            <Label for="review">Password</Label>
                                            <Input 
                                                type="password" 
                                                className="form-control" 
                                                id="review"
                                                placeholder="Enter your password" 
                                                required="" 
                                                onChange={e => setPassword(e.target.value)}
                                            />
                                        </Col>
                                        
                                        <button 
                                            className="btn btn-solid"
                                            onClick={signUp}
                                        >
                                            create Account
                                        </button>

                                    </Row>
                                </div>
                            </div>
                        </Col>
                    </Row>
                </Container>
            </section>

            <FooterOne />
        </>
        //</CommonLayout> 
    )
}

export default Register